use warnings;
use strict;
use Test::More tests => 14;
use Test::Exception;

use POWER::Utils qw( quote_list unquote_list unquote_hash );


my ($out, $plain, $wait);

throws_ok { quote_list(undef) }          qr/can't quote/;
is(quote_list(),            q{},        'quote: empty list');
is(quote_list(1),           q{1},       'quote: simple word');
is(quote_list(q{}),         q{''},      'quote: empty string');
is(quote_list(q{'}),        q{''''},    'quote: single quote');
is(quote_list(q{test}),     q{test},    'quote: word without space');
is(quote_list(q{te st}),    q{'te st'}, 'quote: word with space');
is(quote_list('te','st'),   q{te st},   'quote: two words');

my @l = (1, q{}, q{'}, q{''}, 'test', 'te st', q{ }, q{  });
my %h = @l;
my $s = quote_list(@l);
is_deeply(unquote_list($s), \@l,        'unquote_list: ok');
is_deeply(unquote_hash($s), \%h,        'unquote_hash: ok');

is(unquote_list($s.'XXX'), undef,       'unquote_list: bad data');
is(unquote_hash($s.'XXX'), undef,       'unquote_hash: bad data');

is_deeply(unquote_list($s.' XXX'), [@l,'XXX'],  'unquote_list: odd elements');
is_deeply(unquote_hash($s.' XXX'), undef,       'unquote_hash: odd elements');

